@@ -508,3 +508,12 @@ class User(db.Model):
     user_id = db.Column(db.String(20, 'utf8mb4_0900_ai_ci'), nullable=False, server_default=db.FetchedValue(), info='用户id  手机号 或者 其他')
     user_type = db.Column(db.Integer, nullable=False, server_default=db.FetchedValue(), info='0 身份证 1 护照号')
     mac = db.Column(db.String(17), nullable=False, unique=True, server_default=db.FetchedValue(), info='mac地址')
+
+
+
+class StoreExt(db.Model):
+    __tablename__ = 'store_ext'
+
+    store_id = db.Column(db.Integer, primary_key=True)
+    black_mode = db.Column(db.Integer, nullable=False, server_default=db.FetchedValue(), info='黑名单模式 0 不开启 1 开启')
+    white_prefix = db.Column(db.String(1000), server_default=db.FetchedValue(), info='白名单前缀 多个逗号隔开')
\ No newline at end of file
