@@ -509,3 +509,12 @@ class User(Base):
     user_id = Column(String(20, 'utf8mb4_0900_ai_ci'), nullable=False, server_default=FetchedValue(), info='用户id  手机号 或者 其他')
     user_type = Column(Integer, nullable=False, server_default=FetchedValue(), info='0 身份证 1 护照号')
     mac = Column(String(17), nullable=False, unique=True, server_default=FetchedValue(), info='mac地址')
+
+
+
+class StoreExt(Base):
+    __tablename__ = 'store_ext'
+
+    store_id = Column(Integer, primary_key=True)
+    black_mode = Column(Integer, nullable=False, server_default=FetchedValue(), info='黑名单模式 0 不开启 1 开启')
+    white_prefix = Column(String(1000), server_default=FetchedValue(), info='白名单前缀 多个逗号隔开')
\ No newline at end of file
